%   [T,m]=Max_credM_GRU(Td,Tu,dT,Mmin,lamb,eps,b)
%
%EVALUATES THE MAXIMUM CREDIBLE MAGNITUDE VALUES USING THE UNLIMITED 
%   G-R LED MAGNITUDE DISTRIBUTION MODEL. 
%
% AUTHOR: S. Lasocki 06/2014 within IS-EPOS project.
%
% DESCRIPTION: The assumption on the unlimited Gutenberg-Richter relation 
% leads to the exponential distribution model of magnitude distribution 
% from and above the catalog completness level Mmin. The shape parameter of 
% this distribution and consequently the G-R b-value are calculated at 
% start-up of the stationary hazard assessment services in the
% unlimited Gutenberg-Richter estimation mode.
%
% The maximum credible magnitude for the period of length T
% is the magnitude value whose mean return period is T. 
%
% The maximum credible magnitude values are calculated for periods of 
% length starting from Td up to Tu with step dT.
%
%INPUT:
%   Td - starting period length for maximum credible magnitude calculations
%   Tu - ending period length for maximum credible magnitude calculations
%   dT - period length step for maximum credible magnitude calculations
%   Mmin - lower bound of the distribution - catalog completeness level
%   lamb - mean activity rate for events M>=Mmin
%   eps - length of the round-off interval of magnitudes.
%   b - Gutenberg-Richter b-value
%
%OUTPUT:
%   T - vector of independent variable (period lengths) T=(Td:dT:Tu)
%   m - vector of maximum credible magnitudes of the same length as T
% 
%
% LICENSE
%     This file is a part of the IS-EPOS e-PLATFORM.
%
%     This is free software: you can redistribute it and/or modify it under 
%     the terms of the GNU General Public License as published by the Free 
%     Software Foundation, either version 3 of the License, or 
%     (at your option) any later version.
% 
%     This program is distributed in the hope that it will be useful,
%     but WITHOUT ANY WARRANTY; without even the implied warranty of
%     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%     GNU General Public License for more details.
% 

function [T,m]=Max_credM_GRU(Td,Tu,dT,Mmin,lamb,eps,b)

% -------------- VALIDATION RULES -------------  K_21NOV2016
 if dT<=0;error('Time Step must be greater than 0');end
%----------------------------------------------------------


T=(Td:dT:Tu)';
beta=b*log(10);
m=Mmin-eps/2+1/beta.*log(lamb*T);
end




